"""
Python module generated from Java source file org.yaml.snakeyaml.internal.Logger

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.yaml.snakeyaml.internal import *
from typing import Any, Callable, Iterable, Tuple


class Logger:

    @staticmethod
    def getLogger(name: str) -> "Logger":
        ...


    def isLoggable(self, level: "Level") -> bool:
        ...


    def warn(self, msg: str) -> None:
        ...


    class Level(Enum):

        WARNING = (java.util.logging.Level.FINE)



"""
Python module generated from Java source file org.bukkit.event.player.PlayerTeleportEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import Location
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerTeleportEvent(PlayerMoveEvent):
    """
    Holds information for player teleport events
    """

    def __init__(self, player: "Player", from: "Location", to: "Location"):
        ...


    def __init__(self, player: "Player", from: "Location", to: "Location", cause: "TeleportCause"):
        ...


    def getCause(self) -> "TeleportCause":
        """
        Gets the cause of this teleportation event

        Returns
        - Cause of the event
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    class TeleportCause(Enum):

        ENDER_PEARL = 0
        """
        Indicates the teleporation was caused by a player throwing an Ender
        Pearl
        """
        COMMAND = 1
        """
        Indicates the teleportation was caused by a player executing a
        command
        """
        PLUGIN = 2
        """
        Indicates the teleportation was caused by a plugin
        """
        NETHER_PORTAL = 3
        """
        Indicates the teleportation was caused by a player entering a
        Nether portal
        """
        END_PORTAL = 4
        """
        Indicates the teleportation was caused by a player entering an End
        portal
        """
        SPECTATE = 5
        """
        Indicates the teleportation was caused by a player teleporting to a
        Entity/Player via the spectator menu
        """
        END_GATEWAY = 6
        """
        Indicates the teleportation was caused by a player entering an End
        gateway
        """
        CHORUS_FRUIT = 7
        """
        Indicates the teleportation was caused by a player consuming chorus
        fruit
        """
        DISMOUNT = 8
        """
        Indicates the teleportation was caused by a player exiting a vehicle
        """
        EXIT_BED = 9
        """
        Indicates the teleportation was caused by a player exiting a bed
        """
        UNKNOWN = 10
        """
        Indicates the teleportation was caused by an event not covered by
        this enum
        """



"""
Python module generated from Java source file org.bukkit.event.block.BlockFromToEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockFromToEvent(BlockEvent, Cancellable):
    """
    Represents events with a source block and a destination block, currently
    only applies to liquid (lava and water) and teleporting dragon eggs.
    
    If a Block From To event is cancelled, the block will not move (the liquid
    will not flow).
    """

    def __init__(self, block: "Block", face: "BlockFace"):
        ...


    def __init__(self, block: "Block", toBlock: "Block"):
        ...


    def getFace(self) -> "BlockFace":
        """
        Gets the BlockFace that the block is moving to.

        Returns
        - The BlockFace that the block is moving to
        """
        ...


    def getToBlock(self) -> "Block":
        """
        Convenience method for getting the faced Block.

        Returns
        - The faced Block
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.nio.file.LinkOption

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.nio.file import *
from typing import Any, Callable, Iterable, Tuple


class LinkOption(Enum):

    NOFOLLOW_LINKS = 0
    """
    Do not follow symbolic links.

    See
    - SecureDirectoryStream.newByteChannel
    """



"""
Python module generated from Java source file java.io.PushbackInputStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from typing import Any, Callable, Iterable, Tuple


class PushbackInputStream(FilterInputStream):
    """
    A `PushbackInputStream` adds
    functionality to another input stream, namely
    the  ability to "push back" or "unread" bytes,
    by storing pushed-back bytes in an internal buffer.
    This is useful in situations where
    it is convenient for a fragment of code
    to read an indefinite number of data bytes
    that  are delimited by a particular byte
    value; after reading the terminating byte,
    the  code fragment can "unread" it, so that
    the next read operation on the input stream
    will reread the byte that was pushed back.
    For example, bytes representing the  characters
    constituting an identifier might be terminated
    by a byte representing an  operator character;
    a method whose job is to read just an identifier
    can read until it  sees the operator and
    then push the operator back to be re-read.

    Author(s)
    - Jonathan Payne

    Since
    - 1.0
    """

    def __init__(self, in: "InputStream", size: int):
        """
        Creates a `PushbackInputStream`
        with a pushback buffer of the specified `size`,
        and saves its argument, the input stream
        `in`, for later use. Initially,
        the pushback buffer is empty.

        Arguments
        - in: the input stream from which bytes will be read.
        - size: the size of the pushback buffer.

        Raises
        - IllegalArgumentException: if `size <= 0`

        Since
        - 1.1
        """
        ...


    def __init__(self, in: "InputStream"):
        """
        Creates a `PushbackInputStream`
        with a 1-byte pushback buffer, and saves its argument, the input stream
        `in`, for later use. Initially,
        the pushback buffer is empty.

        Arguments
        - in: the input stream from which bytes will be read.
        """
        ...


    def read(self) -> int:
        """
        Reads the next byte of data from this input stream. The value
        byte is returned as an `int` in the range
        `0` to `255`. If no byte is available
        because the end of the stream has been reached, the value
        `-1` is returned. This method blocks until input data
        is available, the end of the stream is detected, or an exception
        is thrown.
        
         This method returns the most recently pushed-back byte, if there is
        one, and otherwise calls the `read` method of its underlying
        input stream and returns whatever value that method returns.

        Returns
        - the next byte of data, or `-1` if the end of the
                    stream has been reached.

        Raises
        - IOException: if this input stream has been closed by
                    invoking its .close() method,
                    or an I/O error occurs.

        See
        - java.io.InputStream.read()
        """
        ...


    def read(self, b: list[int], off: int, len: int) -> int:
        """
        Reads up to `len` bytes of data from this input stream into
        an array of bytes.  This method first reads any pushed-back bytes; after
        that, if fewer than `len` bytes have been read then it
        reads from the underlying input stream. If `len` is not zero, the method
        blocks until at least 1 byte of input is available; otherwise, no
        bytes are read and `0` is returned.

        Arguments
        - b: the buffer into which the data is read.
        - off: the start offset in the destination array `b`
        - len: the maximum number of bytes read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end of
                    the stream has been reached.

        Raises
        - NullPointerException: If `b` is `null`.
        - IndexOutOfBoundsException: If `off` is negative,
                    `len` is negative, or `len` is greater than
                    `b.length - off`
        - IOException: if this input stream has been closed by
                    invoking its .close() method,
                    or an I/O error occurs.

        See
        - java.io.InputStream.read(byte[], int, int)
        """
        ...


    def unread(self, b: int) -> None:
        """
        Pushes back a byte by copying it to the front of the pushback buffer.
        After this method returns, the next byte to be read will have the value
        `(byte)b`.

        Arguments
        - b: the `int` value whose low-order
                         byte is to be pushed back.

        Raises
        - IOException: If there is not enough room in the pushback
                   buffer for the byte, or this input stream has been closed by
                   invoking its .close() method.
        """
        ...


    def unread(self, b: list[int], off: int, len: int) -> None:
        """
        Pushes back a portion of an array of bytes by copying it to the front
        of the pushback buffer.  After this method returns, the next byte to be
        read will have the value `b[off]`, the byte after that will
        have the value `b[off+1]`, and so forth.

        Arguments
        - b: the byte array to push back.
        - off: the start offset of the data.
        - len: the number of bytes to push back.

        Raises
        - NullPointerException: If `b` is `null`.
        - IOException: If there is not enough room in the pushback
                   buffer for the specified number of bytes,
                   or this input stream has been closed by
                   invoking its .close() method.

        Since
        - 1.1
        """
        ...


    def unread(self, b: list[int]) -> None:
        """
        Pushes back an array of bytes by copying it to the front of the
        pushback buffer.  After this method returns, the next byte to be read
        will have the value `b[0]`, the byte after that will have the
        value `b[1]`, and so forth.

        Arguments
        - b: the byte array to push back

        Raises
        - NullPointerException: If `b` is `null`.
        - IOException: If there is not enough room in the pushback
                   buffer for the specified number of bytes,
                   or this input stream has been closed by
                   invoking its .close() method.

        Since
        - 1.1
        """
        ...


    def available(self) -> int:
        """
        Returns an estimate of the number of bytes that can be read (or
        skipped over) from this input stream without blocking by the next
        invocation of a method for this input stream. The next invocation might be
        the same thread or another thread.  A single read or skip of this
        many bytes will not block, but may read or skip fewer bytes.
        
         The method returns the sum of the number of bytes that have been
        pushed back and the value returned by java.io.FilterInputStream.available available.

        Returns
        - the number of bytes that can be read (or skipped over) from
                    the input stream without blocking.

        Raises
        - IOException: if this input stream has been closed by
                    invoking its .close() method,
                    or an I/O error occurs.

        See
        - java.io.InputStream.available()
        """
        ...


    def skip(self, n: int) -> int:
        """
        Skips over and discards `n` bytes of data from this
        input stream. The `skip` method may, for a variety of
        reasons, end up skipping over some smaller number of bytes,
        possibly zero.  If `n` is negative, no bytes are skipped.
        
         The `skip` method of `PushbackInputStream`
        first skips over the bytes in the pushback buffer, if any.  It then
        calls the `skip` method of the underlying input stream if
        more bytes need to be skipped.  The actual number of bytes skipped
        is returned.

        Arguments
        - n: 

        Returns
        - 

        Raises
        - IOException: if the stream has been closed by
                    invoking its .close() method,
                    `in.skip(n)` throws an IOException,
                    or an I/O error occurs.

        See
        - java.io.InputStream.skip(long n)

        Since
        - 1.2
        """
        ...


    def markSupported(self) -> bool:
        """
        Tests if this input stream supports the `mark` and
        `reset` methods, which it does not.

        Returns
        - `False`, since this class does not support the
                  `mark` and `reset` methods.

        See
        - java.io.InputStream.reset()
        """
        ...


    def mark(self, readlimit: int) -> None:
        """
        Marks the current position in this input stream.
        
         The `mark` method of `PushbackInputStream`
        does nothing.

        Arguments
        - readlimit: the maximum limit of bytes that can be read before
                             the mark position becomes invalid.

        See
        - java.io.InputStream.reset()
        """
        ...


    def reset(self) -> None:
        """
        Repositions this stream to the position at the time the
        `mark` method was last called on this input stream.
        
         The method `reset` for class
        `PushbackInputStream` does nothing except throw an
        `IOException`.

        Raises
        - IOException: if this method is invoked.

        See
        - java.io.IOException
        """
        ...


    def close(self) -> None:
        """
        Closes this input stream and releases any system resources
        associated with the stream.
        Once the stream has been closed, further read(), unread(),
        available(), reset(), or skip() invocations will throw an IOException.
        Closing a previously closed stream has no effect.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.FilteredKeyMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Predicate
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.j2objc.annotations import WeakOuter
from java.util import Collections
from java.util import Iterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class FilteredKeyMultimap(AbstractMultimap, FilteredMultimap):
    """
    Implementation of Multimaps.filterKeys(Multimap, Predicate).

    Author(s)
    - Louis Wasserman
    """

    def unfiltered(self) -> "Multimap"["K", "V"]:
        ...


    def entryPredicate(self) -> "Predicate"["Entry"["K", "V"]]:
        ...


    def size(self) -> int:
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def removeAll(self, key: "Object") -> Iterable["V"]:
        ...


    def clear(self) -> None:
        ...


    def get(self, key: "K") -> Iterable["V"]:
        ...



"""
Python module generated from Java source file com.google.common.graph.EndpointPair

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.base import Objects
from com.google.common.collect import Iterators
from com.google.common.collect import UnmodifiableIterator
from com.google.common.graph import *
from com.google.errorprone.annotations import Immutable
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class EndpointPair(Iterable):
    """
    An immutable pair representing the two endpoints of an edge in a graph. The EndpointPair
    of a directed edge is an ordered pair of nodes (.source() and .target()). The
    EndpointPair of an undirected edge is an unordered pair of nodes (.nodeU() and
    .nodeV()).
    
    The edge is a self-loop if, and only if, the two endpoints are equal.

    Author(s)
    - James Sexton

    Since
    - 20.0
    """

    @staticmethod
    def ordered(source: "N", target: "N") -> "EndpointPair"["N"]:
        """
        Returns an EndpointPair representing the endpoints of a directed edge.
        """
        ...


    @staticmethod
    def unordered(nodeU: "N", nodeV: "N") -> "EndpointPair"["N"]:
        """
        Returns an EndpointPair representing the endpoints of an undirected edge.
        """
        ...


    def source(self) -> "N":
        """
        If this EndpointPair .isOrdered(), returns the node which is the source.

        Raises
        - UnsupportedOperationException: if this EndpointPair is not ordered
        """
        ...


    def target(self) -> "N":
        """
        If this EndpointPair .isOrdered(), returns the node which is the target.

        Raises
        - UnsupportedOperationException: if this EndpointPair is not ordered
        """
        ...


    def nodeU(self) -> "N":
        """
        If this EndpointPair .isOrdered() returns the .source(); otherwise,
        returns an arbitrary (but consistent) endpoint of the origin edge.
        """
        ...


    def nodeV(self) -> "N":
        """
        Returns the node .adjacentNode(Object) adjacent to .nodeU() along the origin
        edge. If this EndpointPair .isOrdered(), this is equal to .target().
        """
        ...


    def adjacentNode(self, node: "N") -> "N":
        """
        Returns the node that is adjacent to `node` along the origin edge.

        Raises
        - IllegalArgumentException: if this EndpointPair does not contain `node`

        Since
        - 20.0 (but the argument type was changed from `Object` to `N` in 31.0)
        """
        ...


    def isOrdered(self) -> bool:
        """
        Returns `True` if this EndpointPair is an ordered pair (i.e. represents the
        endpoints of a directed edge).
        """
        ...


    def iterator(self) -> "UnmodifiableIterator"["N"]:
        """
        Iterates in the order .nodeU(), .nodeV().
        """
        ...


    def equals(self, obj: "Object") -> bool:
        """
        Two ordered EndpointPairs are equal if their .source() and .target()
        are equal. Two unordered EndpointPairs are equal if they contain the same nodes. An
        ordered EndpointPair is never equal to an unordered EndpointPair.
        """
        ...


    def hashCode(self) -> int:
        """
        The hashcode of an ordered EndpointPair is equal to `Objects.hashCode(source(),
        target())`. The hashcode of an unordered EndpointPair is equal to `nodeU().hashCode() + nodeV().hashCode()`.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.scanner.Scanner

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.scanner import *
from org.yaml.snakeyaml.tokens import Token
from typing import Any, Callable, Iterable, Tuple


class Scanner:
    """
    This interface represents an input stream of Tokens.
    
    The parser and the scanner form together the 'Parse' step in the loading process (see chapter 3.1
    of the <a href="http://yaml.org/spec/1.1/">YAML Specification</a>).

    See
    - org.yaml.snakeyaml.tokens.Token
    """

    def checkToken(self, *choices: Tuple["Token.ID", ...]) -> bool:
        """
        Check if the next token is one of the given types.

        Arguments
        - choices: token IDs to match with

        Returns
        - `True` if the next token is one of the given types. Returns
                `False` if no more tokens are available.

        Raises
        - ScannerException: Thrown in case of malformed input.
        """
        ...


    def peekToken(self) -> "Token":
        """
        Return the next token, but do not delete it from the stream.

        Returns
        - The token that will be returned on the next call to .getToken

        Raises
        - ScannerException: Thrown in case of malformed input.
        - IndexOutOfBoundsException: if no more token left
        """
        ...


    def getToken(self) -> "Token":
        """
        Returns the next token.
        
        The token will be removed from the stream. (Every invocation of this method must happen after
        calling either .checkToken or .peekToken()

        Returns
        - the coming token

        Raises
        - ScannerException: Thrown in case of malformed input.
        - IndexOutOfBoundsException: if no more token left
        """
        ...


    def resetDocumentIndex(self) -> None:
        ...



"""
Python module generated from Java source file org.bukkit.metadata.MetadataValueAdapter

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.lang.ref import WeakReference
from org.bukkit.metadata import *
from org.bukkit.plugin import Plugin
from org.bukkit.util import NumberConversions
from typing import Any, Callable, Iterable, Tuple


class MetadataValueAdapter(MetadataValue):
    """
    Optional base class for facilitating MetadataValue implementations.
    
    This provides all the conversion functions for MetadataValue so that
    writing an implementation of MetadataValue is as simple as implementing
    value() and invalidate().
    """

    def getOwningPlugin(self) -> "Plugin":
        ...


    def asInt(self) -> int:
        ...


    def asFloat(self) -> float:
        ...


    def asDouble(self) -> float:
        ...


    def asLong(self) -> int:
        ...


    def asShort(self) -> int:
        ...


    def asByte(self) -> int:
        ...


    def asBoolean(self) -> bool:
        ...


    def asString(self) -> str:
        ...



"""
Python module generated from Java source file java.util.concurrent.CompletableFuture

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.lang.invoke import MethodHandles
from java.lang.invoke import VarHandle
from java.util import Objects
from java.util.concurrent import *
from java.util.concurrent.locks import LockSupport
from java.util.function import BiConsumer
from java.util.function import BiFunction
from java.util.function import Consumer
from java.util.function import Function
from java.util.function import Supplier
from typing import Any, Callable, Iterable, Tuple


class CompletableFuture(Future, CompletionStage):
    """
    A Future that may be explicitly completed (setting its
    value and status), and may be used as a CompletionStage,
    supporting dependent functions and actions that trigger upon its
    completion.
    
    When two or more threads attempt to
    .complete complete,
    .completeExceptionally completeExceptionally, or
    .cancel cancel
    a CompletableFuture, only one of them succeeds.
    
    In addition to these and related methods for directly
    manipulating status and results, CompletableFuture implements
    interface CompletionStage with the following policies: 
    
    - Actions supplied for dependent completions of
    *non-async* methods may be performed by the thread that
    completes the current CompletableFuture, or by any other caller of
    a completion method.
    
    - All *async* methods without an explicit Executor
    argument are performed using the ForkJoinPool.commonPool()
    (unless it does not support a parallelism level of at least two, in
    which case, a new Thread is created to run each task).  This may be
    overridden for non-static methods in subclasses by defining method
    .defaultExecutor(). To simplify monitoring, debugging,
    and tracking, all generated asynchronous tasks are instances of the
    marker interface AsynchronousCompletionTask.  Operations
    with time-delays can use adapter methods defined in this class, for
    example: `supplyAsync(supplier, delayedExecutor(timeout,
    timeUnit))`.  To support methods with delays and timeouts, this
    class maintains at most one daemon thread for triggering and
    cancelling actions, not for running them.
    
    - All CompletionStage methods are implemented independently of
    other public methods, so the behavior of one method is not impacted
    by overrides of others in subclasses.
    
    - All CompletionStage methods return CompletableFutures.  To
    restrict usages to only those methods defined in interface
    CompletionStage, use method .minimalCompletionStage. Or to
    ensure only that clients do not themselves modify a future, use
    method .copy.
    
    
    CompletableFuture also implements Future with the following
    policies: 
    
    - Since (unlike FutureTask) this class has no direct
    control over the computation that causes it to be completed,
    cancellation is treated as just another form of exceptional
    completion.  Method .cancel cancel has the same effect as
    `completeExceptionally(new CancellationException())`. Method
    .isCompletedExceptionally can be used to determine if a
    CompletableFuture completed in any exceptional fashion.
    
    - In case of exceptional completion with a CompletionException,
    methods .get() and .get(long, TimeUnit) throw an
    ExecutionException with the same cause as held in the
    corresponding CompletionException.  To simplify usage in most
    contexts, this class also defines methods .join() and
    .getNow that instead throw the CompletionException directly
    in these cases.
    
    
    Arguments used to pass a completion result (that is, for
    parameters of type `T`) for methods accepting them may be
    null, but passing a null value for any other parameter will result
    in a NullPointerException being thrown.
    
    Subclasses of this class should normally override the "virtual
    constructor" method .newIncompleteFuture, which establishes
    the concrete type returned by CompletionStage methods. For example,
    here is a class that substitutes a different default Executor and
    disables the `obtrude` methods:
    
    ``` `class MyCompletableFuture<T> extends CompletableFuture<T> {
      static final Executor myExecutor = ...;
      public MyCompletableFuture() {`
      public <U> CompletableFuture<U> newIncompleteFuture() {
        return new MyCompletableFuture<U>(); }
      public Executor defaultExecutor() {
        return myExecutor; }
      public void obtrudeValue(T value) {
        throw new UnsupportedOperationException(); }
      public void obtrudeException(Throwable ex) {
        throw new UnsupportedOperationException(); }
    }}```
    
    Type `<T>`: The result type returned by this future's `join`
    and `get` methods

    Author(s)
    - Doug Lea

    Since
    - 1.8
    """

    def __init__(self):
        """
        Creates a new incomplete CompletableFuture.
        """
        ...


    @staticmethod
    def supplyAsync(supplier: "Supplier"["U"]) -> "CompletableFuture"["U"]:
        """
        Returns a new CompletableFuture that is asynchronously completed
        by a task running in the ForkJoinPool.commonPool() with
        the value obtained by calling the given Supplier.
        
        Type `<U>`: the function's return type

        Arguments
        - supplier: a function returning the value to be used
        to complete the returned CompletableFuture

        Returns
        - the new CompletableFuture
        """
        ...


    @staticmethod
    def supplyAsync(supplier: "Supplier"["U"], executor: "Executor") -> "CompletableFuture"["U"]:
        """
        Returns a new CompletableFuture that is asynchronously completed
        by a task running in the given executor with the value obtained
        by calling the given Supplier.
        
        Type `<U>`: the function's return type

        Arguments
        - supplier: a function returning the value to be used
        to complete the returned CompletableFuture
        - executor: the executor to use for asynchronous execution

        Returns
        - the new CompletableFuture
        """
        ...


    @staticmethod
    def runAsync(runnable: "Runnable") -> "CompletableFuture"["Void"]:
        """
        Returns a new CompletableFuture that is asynchronously completed
        by a task running in the ForkJoinPool.commonPool() after
        it runs the given action.

        Arguments
        - runnable: the action to run before completing the
        returned CompletableFuture

        Returns
        - the new CompletableFuture
        """
        ...


    @staticmethod
    def runAsync(runnable: "Runnable", executor: "Executor") -> "CompletableFuture"["Void"]:
        """
        Returns a new CompletableFuture that is asynchronously completed
        by a task running in the given executor after it runs the given
        action.

        Arguments
        - runnable: the action to run before completing the
        returned CompletableFuture
        - executor: the executor to use for asynchronous execution

        Returns
        - the new CompletableFuture
        """
        ...


    @staticmethod
    def completedFuture(value: "U") -> "CompletableFuture"["U"]:
        """
        Returns a new CompletableFuture that is already completed with
        the given value.
        
        Type `<U>`: the type of the value

        Arguments
        - value: the value

        Returns
        - the completed CompletableFuture
        """
        ...


    def isDone(self) -> bool:
        """
        Returns `True` if completed in any fashion: normally,
        exceptionally, or via cancellation.

        Returns
        - `True` if completed
        """
        ...


    def get(self) -> "T":
        """
        Waits if necessary for this future to complete, and then
        returns its result.

        Returns
        - the result value

        Raises
        - CancellationException: if this future was cancelled
        - ExecutionException: if this future completed exceptionally
        - InterruptedException: if the current thread was interrupted
        while waiting
        """
        ...


    def get(self, timeout: int, unit: "TimeUnit") -> "T":
        """
        Waits if necessary for at most the given time for this future
        to complete, and then returns its result, if available.

        Arguments
        - timeout: the maximum time to wait
        - unit: the time unit of the timeout argument

        Returns
        - the result value

        Raises
        - CancellationException: if this future was cancelled
        - ExecutionException: if this future completed exceptionally
        - InterruptedException: if the current thread was interrupted
        while waiting
        - TimeoutException: if the wait timed out
        """
        ...


    def join(self) -> "T":
        """
        Returns the result value when complete, or throws an
        (unchecked) exception if completed exceptionally. To better
        conform with the use of common functional forms, if a
        computation involved in the completion of this
        CompletableFuture threw an exception, this method throws an
        (unchecked) CompletionException with the underlying
        exception as its cause.

        Returns
        - the result value

        Raises
        - CancellationException: if the computation was cancelled
        - CompletionException: if this future completed
        exceptionally or a completion computation threw an exception
        """
        ...


    def getNow(self, valueIfAbsent: "T") -> "T":
        """
        Returns the result value (or throws any encountered exception)
        if completed, else returns the given valueIfAbsent.

        Arguments
        - valueIfAbsent: the value to return if not completed

        Returns
        - the result value, if completed, else the given valueIfAbsent

        Raises
        - CancellationException: if the computation was cancelled
        - CompletionException: if this future completed
        exceptionally or a completion computation threw an exception
        """
        ...


    def complete(self, value: "T") -> bool:
        """
        If not already completed, sets the value returned by .get() and related methods to the given value.

        Arguments
        - value: the result value

        Returns
        - `True` if this invocation caused this CompletableFuture
        to transition to a completed state, else `False`
        """
        ...


    def completeExceptionally(self, ex: "Throwable") -> bool:
        """
        If not already completed, causes invocations of .get()
        and related methods to throw the given exception.

        Arguments
        - ex: the exception

        Returns
        - `True` if this invocation caused this CompletableFuture
        to transition to a completed state, else `False`
        """
        ...


    def thenApply(self, fn: "Function"["T", "U"]) -> "CompletableFuture"["U"]:
        ...


    def thenApplyAsync(self, fn: "Function"["T", "U"]) -> "CompletableFuture"["U"]:
        ...


    def thenApplyAsync(self, fn: "Function"["T", "U"], executor: "Executor") -> "CompletableFuture"["U"]:
        ...


    def thenAccept(self, action: "Consumer"["T"]) -> "CompletableFuture"["Void"]:
        ...


    def thenAcceptAsync(self, action: "Consumer"["T"]) -> "CompletableFuture"["Void"]:
        ...


    def thenAcceptAsync(self, action: "Consumer"["T"], executor: "Executor") -> "CompletableFuture"["Void"]:
        ...


    def thenRun(self, action: "Runnable") -> "CompletableFuture"["Void"]:
        ...


    def thenRunAsync(self, action: "Runnable") -> "CompletableFuture"["Void"]:
        ...


    def thenRunAsync(self, action: "Runnable", executor: "Executor") -> "CompletableFuture"["Void"]:
        ...


    def thenCombine(self, other: "CompletionStage"["U"], fn: "BiFunction"["T", "U", "V"]) -> "CompletableFuture"["V"]:
        ...


    def thenCombineAsync(self, other: "CompletionStage"["U"], fn: "BiFunction"["T", "U", "V"]) -> "CompletableFuture"["V"]:
        ...


    def thenCombineAsync(self, other: "CompletionStage"["U"], fn: "BiFunction"["T", "U", "V"], executor: "Executor") -> "CompletableFuture"["V"]:
        ...


    def thenAcceptBoth(self, other: "CompletionStage"["U"], action: "BiConsumer"["T", "U"]) -> "CompletableFuture"["Void"]:
        ...


    def thenAcceptBothAsync(self, other: "CompletionStage"["U"], action: "BiConsumer"["T", "U"]) -> "CompletableFuture"["Void"]:
        ...


    def thenAcceptBothAsync(self, other: "CompletionStage"["U"], action: "BiConsumer"["T", "U"], executor: "Executor") -> "CompletableFuture"["Void"]:
        ...


    def runAfterBoth(self, other: "CompletionStage"[Any], action: "Runnable") -> "CompletableFuture"["Void"]:
        ...


    def runAfterBothAsync(self, other: "CompletionStage"[Any], action: "Runnable") -> "CompletableFuture"["Void"]:
        ...


    def runAfterBothAsync(self, other: "CompletionStage"[Any], action: "Runnable", executor: "Executor") -> "CompletableFuture"["Void"]:
        ...


    def applyToEither(self, other: "CompletionStage"["T"], fn: "Function"["T", "U"]) -> "CompletableFuture"["U"]:
        ...


    def applyToEitherAsync(self, other: "CompletionStage"["T"], fn: "Function"["T", "U"]) -> "CompletableFuture"["U"]:
        ...


    def applyToEitherAsync(self, other: "CompletionStage"["T"], fn: "Function"["T", "U"], executor: "Executor") -> "CompletableFuture"["U"]:
        ...


    def acceptEither(self, other: "CompletionStage"["T"], action: "Consumer"["T"]) -> "CompletableFuture"["Void"]:
        ...


    def acceptEitherAsync(self, other: "CompletionStage"["T"], action: "Consumer"["T"]) -> "CompletableFuture"["Void"]:
        ...


    def acceptEitherAsync(self, other: "CompletionStage"["T"], action: "Consumer"["T"], executor: "Executor") -> "CompletableFuture"["Void"]:
        ...


    def runAfterEither(self, other: "CompletionStage"[Any], action: "Runnable") -> "CompletableFuture"["Void"]:
        ...


    def runAfterEitherAsync(self, other: "CompletionStage"[Any], action: "Runnable") -> "CompletableFuture"["Void"]:
        ...


    def runAfterEitherAsync(self, other: "CompletionStage"[Any], action: "Runnable", executor: "Executor") -> "CompletableFuture"["Void"]:
        ...


    def thenCompose(self, fn: "Function"["T", "CompletionStage"["U"]]) -> "CompletableFuture"["U"]:
        ...


    def thenComposeAsync(self, fn: "Function"["T", "CompletionStage"["U"]]) -> "CompletableFuture"["U"]:
        ...


    def thenComposeAsync(self, fn: "Function"["T", "CompletionStage"["U"]], executor: "Executor") -> "CompletableFuture"["U"]:
        ...


    def whenComplete(self, action: "BiConsumer"["T", "Throwable"]) -> "CompletableFuture"["T"]:
        ...


    def whenCompleteAsync(self, action: "BiConsumer"["T", "Throwable"]) -> "CompletableFuture"["T"]:
        ...


    def whenCompleteAsync(self, action: "BiConsumer"["T", "Throwable"], executor: "Executor") -> "CompletableFuture"["T"]:
        ...


    def handle(self, fn: "BiFunction"["T", "Throwable", "U"]) -> "CompletableFuture"["U"]:
        ...


    def handleAsync(self, fn: "BiFunction"["T", "Throwable", "U"]) -> "CompletableFuture"["U"]:
        ...


    def handleAsync(self, fn: "BiFunction"["T", "Throwable", "U"], executor: "Executor") -> "CompletableFuture"["U"]:
        ...


    def toCompletableFuture(self) -> "CompletableFuture"["T"]:
        """
        Returns this CompletableFuture.

        Returns
        - this CompletableFuture
        """
        ...


    def exceptionally(self, fn: "Function"["Throwable", "T"]) -> "CompletableFuture"["T"]:
        ...


    def exceptionallyAsync(self, fn: "Function"["Throwable", "T"]) -> "CompletableFuture"["T"]:
        ...


    def exceptionallyAsync(self, fn: "Function"["Throwable", "T"], executor: "Executor") -> "CompletableFuture"["T"]:
        ...


    def exceptionallyCompose(self, fn: "Function"["Throwable", "CompletionStage"["T"]]) -> "CompletableFuture"["T"]:
        ...


    def exceptionallyComposeAsync(self, fn: "Function"["Throwable", "CompletionStage"["T"]]) -> "CompletableFuture"["T"]:
        ...


    def exceptionallyComposeAsync(self, fn: "Function"["Throwable", "CompletionStage"["T"]], executor: "Executor") -> "CompletableFuture"["T"]:
        ...


    @staticmethod
    def allOf(*cfs: Tuple["CompletableFuture"[Any], ...]) -> "CompletableFuture"["Void"]:
        """
        Returns a new CompletableFuture that is completed when all of
        the given CompletableFutures complete.  If any of the given
        CompletableFutures complete exceptionally, then the returned
        CompletableFuture also does so, with a CompletionException
        holding this exception as its cause.  Otherwise, the results,
        if any, of the given CompletableFutures are not reflected in
        the returned CompletableFuture, but may be obtained by
        inspecting them individually. If no CompletableFutures are
        provided, returns a CompletableFuture completed with the value
        `null`.
        
        Among the applications of this method is to await completion
        of a set of independent CompletableFutures before continuing a
        program, as in: `CompletableFuture.allOf(c1, c2,
        c3).join();`.

        Arguments
        - cfs: the CompletableFutures

        Returns
        - a new CompletableFuture that is completed when all of the
        given CompletableFutures complete

        Raises
        - NullPointerException: if the array or any of its elements are
        `null`
        """
        ...


    @staticmethod
    def anyOf(*cfs: Tuple["CompletableFuture"[Any], ...]) -> "CompletableFuture"["Object"]:
        """
        Returns a new CompletableFuture that is completed when any of
        the given CompletableFutures complete, with the same result.
        Otherwise, if it completed exceptionally, the returned
        CompletableFuture also does so, with a CompletionException
        holding this exception as its cause.  If no CompletableFutures
        are provided, returns an incomplete CompletableFuture.

        Arguments
        - cfs: the CompletableFutures

        Returns
        - a new CompletableFuture that is completed with the
        result or exception of any of the given CompletableFutures when
        one completes

        Raises
        - NullPointerException: if the array or any of its elements are
        `null`
        """
        ...


    def cancel(self, mayInterruptIfRunning: bool) -> bool:
        """
        If not already completed, completes this CompletableFuture with
        a CancellationException. Dependent CompletableFutures
        that have not already completed will also complete
        exceptionally, with a CompletionException caused by
        this `CancellationException`.

        Arguments
        - mayInterruptIfRunning: this value has no effect in this
        implementation because interrupts are not used to control
        processing.

        Returns
        - `True` if this task is now cancelled
        """
        ...


    def isCancelled(self) -> bool:
        """
        Returns `True` if this CompletableFuture was cancelled
        before it completed normally.

        Returns
        - `True` if this CompletableFuture was cancelled
        before it completed normally
        """
        ...


    def isCompletedExceptionally(self) -> bool:
        """
        Returns `True` if this CompletableFuture completed
        exceptionally, in any way. Possible causes include
        cancellation, explicit invocation of `completeExceptionally`, and abrupt termination of a
        CompletionStage action.

        Returns
        - `True` if this CompletableFuture completed
        exceptionally
        """
        ...


    def obtrudeValue(self, value: "T") -> None:
        """
        Forcibly sets or resets the value subsequently returned by
        method .get() and related methods, whether or not
        already completed. This method is designed for use only in
        error recovery actions, and even in such situations may result
        in ongoing dependent completions using established versus
        overwritten outcomes.

        Arguments
        - value: the completion value
        """
        ...


    def obtrudeException(self, ex: "Throwable") -> None:
        """
        Forcibly causes subsequent invocations of method .get()
        and related methods to throw the given exception, whether or
        not already completed. This method is designed for use only in
        error recovery actions, and even in such situations may result
        in ongoing dependent completions using established versus
        overwritten outcomes.

        Arguments
        - ex: the exception

        Raises
        - NullPointerException: if the exception is null
        """
        ...


    def getNumberOfDependents(self) -> int:
        """
        Returns the estimated number of CompletableFutures whose
        completions are awaiting completion of this CompletableFuture.
        This method is designed for use in monitoring system state, not
        for synchronization control.

        Returns
        - the number of dependent CompletableFutures
        """
        ...


    def toString(self) -> str:
        """
        Returns a string identifying this CompletableFuture, as well as
        its completion state.  The state, in brackets, contains the
        String `"Completed Normally"` or the String `"Completed Exceptionally"`, or the String `"Not
        completed"` followed by the number of CompletableFutures
        dependent upon its completion, if any.

        Returns
        - a string identifying this CompletableFuture, as well as its state
        """
        ...


    def newIncompleteFuture(self) -> "CompletableFuture"["U"]:
        """
        Returns a new incomplete CompletableFuture of the type to be
        returned by a CompletionStage method. Subclasses should
        normally override this method to return an instance of the same
        class as this CompletableFuture. The default implementation
        returns an instance of class CompletableFuture.
        
        Type `<U>`: the type of the value

        Returns
        - a new CompletableFuture

        Since
        - 9
        """
        ...


    def defaultExecutor(self) -> "Executor":
        """
        Returns the default Executor used for async methods that do not
        specify an Executor. This class uses the ForkJoinPool.commonPool() if it supports more than one
        parallel thread, or else an Executor using one thread per async
        task.  This method may be overridden in subclasses to return
        an Executor that provides at least one independent thread.

        Returns
        - the executor

        Since
        - 9
        """
        ...


    def copy(self) -> "CompletableFuture"["T"]:
        """
        Returns a new CompletableFuture that is completed normally with
        the same value as this CompletableFuture when it completes
        normally. If this CompletableFuture completes exceptionally,
        then the returned CompletableFuture completes exceptionally
        with a CompletionException with this exception as cause. The
        behavior is equivalent to `thenApply(x -> x)`. This
        method may be useful as a form of "defensive copying", to
        prevent clients from completing, while still being able to
        arrange dependent actions.

        Returns
        - the new CompletableFuture

        Since
        - 9
        """
        ...


    def minimalCompletionStage(self) -> "CompletionStage"["T"]:
        """
        Returns a new CompletionStage that is completed normally with
        the same value as this CompletableFuture when it completes
        normally, and cannot be independently completed or otherwise
        used in ways not defined by the methods of interface CompletionStage.  If this CompletableFuture completes
        exceptionally, then the returned CompletionStage completes
        exceptionally with a CompletionException with this exception as
        cause.
        
        Unless overridden by a subclass, a new non-minimal
        CompletableFuture with all methods available can be obtained from
        a minimal CompletionStage via .toCompletableFuture().
        For example, completion of a minimal stage can be awaited by
        
        ``` `minimalStage.toCompletableFuture().join();````

        Returns
        - the new CompletionStage

        Since
        - 9
        """
        ...


    def completeAsync(self, supplier: "Supplier"["T"], executor: "Executor") -> "CompletableFuture"["T"]:
        """
        Completes this CompletableFuture with the result of
        the given Supplier function invoked from an asynchronous
        task using the given executor.

        Arguments
        - supplier: a function returning the value to be used
        to complete this CompletableFuture
        - executor: the executor to use for asynchronous execution

        Returns
        - this CompletableFuture

        Since
        - 9
        """
        ...


    def completeAsync(self, supplier: "Supplier"["T"]) -> "CompletableFuture"["T"]:
        """
        Completes this CompletableFuture with the result of the given
        Supplier function invoked from an asynchronous task using the
        default executor.

        Arguments
        - supplier: a function returning the value to be used
        to complete this CompletableFuture

        Returns
        - this CompletableFuture

        Since
        - 9
        """
        ...


    def orTimeout(self, timeout: int, unit: "TimeUnit") -> "CompletableFuture"["T"]:
        """
        Exceptionally completes this CompletableFuture with
        a TimeoutException if not otherwise completed
        before the given timeout.

        Arguments
        - timeout: how long to wait before completing exceptionally
               with a TimeoutException, in units of `unit`
        - unit: a `TimeUnit` determining how to interpret the
               `timeout` parameter

        Returns
        - this CompletableFuture

        Since
        - 9
        """
        ...


    def completeOnTimeout(self, value: "T", timeout: int, unit: "TimeUnit") -> "CompletableFuture"["T"]:
        """
        Completes this CompletableFuture with the given value if not
        otherwise completed before the given timeout.

        Arguments
        - value: the value to use upon timeout
        - timeout: how long to wait before completing normally
               with the given value, in units of `unit`
        - unit: a `TimeUnit` determining how to interpret the
               `timeout` parameter

        Returns
        - this CompletableFuture

        Since
        - 9
        """
        ...


    @staticmethod
    def delayedExecutor(delay: int, unit: "TimeUnit", executor: "Executor") -> "Executor":
        """
        Returns a new Executor that submits a task to the given base
        executor after the given delay (or no delay if non-positive).
        Each delay commences upon invocation of the returned executor's
        `execute` method.

        Arguments
        - delay: how long to delay, in units of `unit`
        - unit: a `TimeUnit` determining how to interpret the
               `delay` parameter
        - executor: the base executor

        Returns
        - the new delayed executor

        Since
        - 9
        """
        ...


    @staticmethod
    def delayedExecutor(delay: int, unit: "TimeUnit") -> "Executor":
        """
        Returns a new Executor that submits a task to the default
        executor after the given delay (or no delay if non-positive).
        Each delay commences upon invocation of the returned executor's
        `execute` method.

        Arguments
        - delay: how long to delay, in units of `unit`
        - unit: a `TimeUnit` determining how to interpret the
               `delay` parameter

        Returns
        - the new delayed executor

        Since
        - 9
        """
        ...


    @staticmethod
    def completedStage(value: "U") -> "CompletionStage"["U"]:
        """
        Returns a new CompletionStage that is already completed with
        the given value and supports only those methods in
        interface CompletionStage.
        
        Type `<U>`: the type of the value

        Arguments
        - value: the value

        Returns
        - the completed CompletionStage

        Since
        - 9
        """
        ...


    @staticmethod
    def failedFuture(ex: "Throwable") -> "CompletableFuture"["U"]:
        """
        Returns a new CompletableFuture that is already completed
        exceptionally with the given exception.
        
        Type `<U>`: the type of the value

        Arguments
        - ex: the exception

        Returns
        - the exceptionally completed CompletableFuture

        Since
        - 9
        """
        ...


    @staticmethod
    def failedStage(ex: "Throwable") -> "CompletionStage"["U"]:
        """
        Returns a new CompletionStage that is already completed
        exceptionally with the given exception and supports only those
        methods in interface CompletionStage.
        
        Type `<U>`: the type of the value

        Arguments
        - ex: the exception

        Returns
        - the exceptionally completed CompletionStage

        Since
        - 9
        """
        ...


    class AsynchronousCompletionTask:
        """
        A marker interface identifying asynchronous tasks produced by
        `async` methods. This may be useful for monitoring,
        debugging, and tracking asynchronous activities.

        Since
        - 1.8
        """





"""
Python module generated from Java source file org.bukkit.event.inventory.FurnaceBurnEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import BlockEvent
from org.bukkit.event.inventory import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class FurnaceBurnEvent(BlockEvent, Cancellable):
    """
    Called when an ItemStack is successfully burned as fuel in a furnace.
    """

    def __init__(self, furnace: "Block", fuel: "ItemStack", burnTime: int):
        ...


    def getFuel(self) -> "ItemStack":
        """
        Gets the fuel ItemStack for this event

        Returns
        - the fuel ItemStack
        """
        ...


    def getBurnTime(self) -> int:
        """
        Gets the burn time for this fuel

        Returns
        - the burn time for this fuel
        """
        ...


    def setBurnTime(self, burnTime: int) -> None:
        """
        Sets the burn time for this fuel

        Arguments
        - burnTime: the burn time for this fuel
        """
        ...


    def isBurning(self) -> bool:
        """
        Gets whether the furnace's fuel is burning or not.

        Returns
        - whether the furnace's fuel is burning or not.
        """
        ...


    def setBurning(self, burning: bool) -> None:
        """
        Sets whether the furnace's fuel is burning or not.

        Arguments
        - burning: True if the furnace's fuel is burning
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.gson.ToNumberPolicy

Java source file obtained from artifact gson version 2.11.0

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal import LazilyParsedNumber
from com.google.gson.internal import NumberLimits
from com.google.gson.stream import JsonReader
from com.google.gson.stream import MalformedJsonException
from enum import Enum
from java.io import IOException
from java.math import BigDecimal
from typing import Any, Callable, Iterable, Tuple


class ToNumberPolicy(Enum):
    """
    An enumeration that defines two standard number reading strategies and a couple of strategies to
    overcome some historical Gson limitations while deserializing numbers as Object and
    Number.

    See
    - ToNumberStrategy

    Since
    - 2.8.9
    """

    DOUBLE = 0
    """
    Using this policy will ensure that numbers will be read as Double values. This is the
    default strategy used during deserialization of numbers as Object.
    """
    LAZILY_PARSED_NUMBER = 1
    """
    Using this policy will ensure that numbers will be read as a lazily parsed number backed by a
    string. This is the default strategy used during deserialization of numbers as Number.
    """
    LONG_OR_DOUBLE = 2
    """
    Using this policy will ensure that numbers will be read as Long or Double
    values depending on how JSON numbers are represented: `Long` if the JSON number can be
    parsed as a `Long` value, or otherwise `Double` if it can be parsed as a `Double` value. If the parsed double-precision number results in a positive or negative infinity
    (Double.isInfinite()) or a NaN (Double.isNaN()) value and the `JsonReader` is not JsonReader.isLenient() lenient, a MalformedJsonException is
    thrown.
    """
    BIG_DECIMAL = 3
    """
    Using this policy will ensure that numbers will be read as numbers of arbitrary length using
    BigDecimal.
    """



"""
Python module generated from Java source file java.util.function.LongConsumer

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Objects
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class LongConsumer:
    """
    Represents an operation that accepts a single `long`-valued argument and
    returns no result.  This is the primitive type specialization of
    Consumer for `long`.  Unlike most other functional interfaces,
    `LongConsumer` is expected to operate via side-effects.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .accept(long).

    See
    - Consumer

    Since
    - 1.8
    """

    def accept(self, value: int) -> None:
        """
        Performs this operation on the given argument.

        Arguments
        - value: the input argument
        """
        ...


    def andThen(self, after: "LongConsumer") -> "LongConsumer":
        """
        Returns a composed `LongConsumer` that performs, in sequence, this
        operation followed by the `after` operation. If performing either
        operation throws an exception, it is relayed to the caller of the
        composed operation.  If performing this operation throws an exception,
        the `after` operation will not be performed.

        Arguments
        - after: the operation to perform after this operation

        Returns
        - a composed `LongConsumer` that performs in sequence this
        operation followed by the `after` operation

        Raises
        - NullPointerException: if `after` is null
        """
        ...



"""
Python module generated from Java source file org.bukkit.command.TabCompleter

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class TabCompleter:
    """
    Represents a class which can suggest tab completions for commands.
    """

    def onTabComplete(self, sender: "CommandSender", command: "Command", label: str, args: list[str]) -> list[str]:
        """
        Requests a list of possible completions for a command argument.

        Arguments
        - sender: Source of the command.  For players tab-completing a
            command inside of a command block, this will be the player, not
            the command block.
        - command: Command which was executed
        - label: Alias of the command which was used
        - args: The arguments passed to the command, including final
            partial argument to be completed

        Returns
        - A List of possible completions for the final argument, or null
            to default to the command executor
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.ScheduledFuture

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import *
from typing import Any, Callable, Iterable, Tuple


class ScheduledFuture(Delayed, Future):
    """
    A delayed result-bearing action that can be cancelled.
    Usually a scheduled future is the result of scheduling
    a task with a ScheduledExecutorService.
    
    Type `<V>`: The result type returned by this Future

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """





"""
Python module generated from Java source file java.util.concurrent.CountDownLatch

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import *
from java.util.concurrent.locks import AbstractQueuedSynchronizer
from typing import Any, Callable, Iterable, Tuple


class CountDownLatch:
    """
    A synchronization aid that allows one or more threads to wait until
    a set of operations being performed in other threads completes.
    
    A `CountDownLatch` is initialized with a given *count*.
    The .await await methods block until the current count reaches
    zero due to invocations of the .countDown method, after which
    all waiting threads are released and any subsequent invocations of
    .await await return immediately.  This is a one-shot phenomenon
    -- the count cannot be reset.  If you need a version that resets the
    count, consider using a CyclicBarrier.
    
    A `CountDownLatch` is a versatile synchronization tool
    and can be used for a number of purposes.  A
    `CountDownLatch` initialized with a count of one serves as a
    simple on/off latch, or gate: all threads invoking .await await
    wait at the gate until it is opened by a thread invoking .countDown.  A `CountDownLatch` initialized to *N*
    can be used to make one thread wait until *N* threads have
    completed some action, or some action has been completed N times.
    
    A useful property of a `CountDownLatch` is that it
    doesn't require that threads calling `countDown` wait for
    the count to reach zero before proceeding, it simply prevents any
    thread from proceeding past an .await await until all
    threads could pass.
    
    **Sample usage:** Here is a pair of classes in which a group
    of worker threads use two countdown latches:
    
    - The first is a start signal that prevents any worker from proceeding
    until the driver is ready for them to proceed;
    - The second is a completion signal that allows the driver to wait
    until all workers have completed.
    
    
    ``` `class Driver { // ...
      void main() throws InterruptedException {
        CountDownLatch startSignal = new CountDownLatch(1);
        CountDownLatch doneSignal = new CountDownLatch(N);
    
        for (int i = 0; i < N; ++i) // create and start threads
          new Thread(new Worker(startSignal, doneSignal)).start();
    
        doSomethingElse();            // don't let run yet
        startSignal.countDown();      // let all threads proceed
        doSomethingElse();
        doneSignal.await();           // wait for all to finish`
    }
    
    class Worker implements Runnable {
      private final CountDownLatch startSignal;
      private final CountDownLatch doneSignal;
      Worker(CountDownLatch startSignal, CountDownLatch doneSignal) {
        this.startSignal = startSignal;
        this.doneSignal = doneSignal;
      }
      public void run() {
        try {
          startSignal.await();
          doWork();
          doneSignal.countDown();
        } catch (InterruptedException ex) {} // return;
      }
    
      void doWork() { ... }
    }}```
    
    Another typical usage would be to divide a problem into N parts,
    describe each part with a Runnable that executes that portion and
    counts down on the latch, and queue all the Runnables to an
    Executor.  When all sub-parts are complete, the coordinating thread
    will be able to pass through await. (When threads must repeatedly
    count down in this way, instead use a CyclicBarrier.)
    
    ``` `class Driver2 { // ...
      void main() throws InterruptedException {
        CountDownLatch doneSignal = new CountDownLatch(N);
        Executor e = ...;
    
        for (int i = 0; i < N; ++i) // create and start threads
          e.execute(new WorkerRunnable(doneSignal, i));
    
        doneSignal.await();           // wait for all to finish`
    }
    
    class WorkerRunnable implements Runnable {
      private final CountDownLatch doneSignal;
      private final int i;
      WorkerRunnable(CountDownLatch doneSignal, int i) {
        this.doneSignal = doneSignal;
        this.i = i;
      }
      public void run() {
        doWork();
        doneSignal.countDown();
      }
    
      void doWork() { ... }
    }}```
    
    Memory consistency effects: Until the count reaches
    zero, actions in a thread prior to calling
    `countDown()`
    <a href="package-summary.html#MemoryVisibility">*happen-before*</a>
    actions following a successful return from a corresponding
    `await()` in another thread.

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def __init__(self, count: int):
        """
        Constructs a `CountDownLatch` initialized with the given count.

        Arguments
        - count: the number of times .countDown must be invoked
               before threads can pass through .await

        Raises
        - IllegalArgumentException: if `count` is negative
        """
        ...


    def await(self) -> None:
        """
        Causes the current thread to wait until the latch has counted down to
        zero, unless the thread is Thread.interrupt interrupted.
        
        If the current count is zero then this method returns immediately.
        
        If the current count is greater than zero then the current
        thread becomes disabled for thread scheduling purposes and lies
        dormant until one of two things happen:
        
        - The count reaches zero due to invocations of the
        .countDown method; or
        - Some other thread Thread.interrupt interrupts
        the current thread.
        
        
        If the current thread:
        
        - has its interrupted status set on entry to this method; or
        - is Thread.interrupt interrupted while waiting,
        
        then InterruptedException is thrown and the current thread's
        interrupted status is cleared.

        Raises
        - InterruptedException: if the current thread is interrupted
                while waiting
        """
        ...


    def await(self, timeout: int, unit: "TimeUnit") -> bool:
        """
        Causes the current thread to wait until the latch has counted down to
        zero, unless the thread is Thread.interrupt interrupted,
        or the specified waiting time elapses.
        
        If the current count is zero then this method returns immediately
        with the value `True`.
        
        If the current count is greater than zero then the current
        thread becomes disabled for thread scheduling purposes and lies
        dormant until one of three things happen:
        
        - The count reaches zero due to invocations of the
        .countDown method; or
        - Some other thread Thread.interrupt interrupts
        the current thread; or
        - The specified waiting time elapses.
        
        
        If the count reaches zero then the method returns with the
        value `True`.
        
        If the current thread:
        
        - has its interrupted status set on entry to this method; or
        - is Thread.interrupt interrupted while waiting,
        
        then InterruptedException is thrown and the current thread's
        interrupted status is cleared.
        
        If the specified waiting time elapses then the value `False`
        is returned.  If the time is less than or equal to zero, the method
        will not wait at all.

        Arguments
        - timeout: the maximum time to wait
        - unit: the time unit of the `timeout` argument

        Returns
        - `True` if the count reached zero and `False`
                if the waiting time elapsed before the count reached zero

        Raises
        - InterruptedException: if the current thread is interrupted
                while waiting
        """
        ...


    def countDown(self) -> None:
        """
        Decrements the count of the latch, releasing all waiting threads if
        the count reaches zero.
        
        If the current count is greater than zero then it is decremented.
        If the new count is zero then all waiting threads are re-enabled for
        thread scheduling purposes.
        
        If the current count equals zero then nothing happens.
        """
        ...


    def getCount(self) -> int:
        """
        Returns the current count.
        
        This method is typically used for debugging and testing purposes.

        Returns
        - the current count
        """
        ...


    def toString(self) -> str:
        """
        Returns a string identifying this latch, as well as its state.
        The state, in brackets, includes the String `"Count ="`
        followed by the current count.

        Returns
        - a string identifying this latch, as well as its state
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingIterator

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Iterator
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingIterator(ForwardingObject, Iterator):
    """
    An iterator which forwards all its method calls to another iterator. Subclasses should override
    one or more methods to modify the behavior of the backing iterator as desired per the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **`default` method warning:** This class forwards calls to *only some* `default` methods. Specifically, it forwards calls only for methods that existed <a
    href="https://docs.oracle.com/javase/7/docs/api/java/util/Iterator.html">before `default`
    methods were introduced</a>. For newer methods, like `forEachRemaining`, it inherits their
    default implementations. When those implementations invoke methods, they invoke methods on the
    `ForwardingIterator`.

    Author(s)
    - Kevin Bourrillion

    Since
    - 2.0
    """

    def hasNext(self) -> bool:
        ...


    def next(self) -> "T":
        ...


    def remove(self) -> None:
        ...



"""
Python module generated from Java source file java.net.URLDecoder

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.net import *
from java.nio.charset import Charset
from java.nio.charset import IllegalCharsetNameException
from java.nio.charset import UnsupportedCharsetException
from java.util import Objects
from typing import Any, Callable, Iterable, Tuple


class URLDecoder:

    @staticmethod
    def decode(s: str) -> str:
        """
        Decodes a `x-www-form-urlencoded` string.
        The platform's default encoding is used to determine what characters
        are represented by any consecutive sequences of the form
        "*`%xy`*".

        Arguments
        - s: the `String` to decode

        Returns
        - the newly decoded `String`

        Deprecated
        - The resulting string may vary depending on the platform's
                 default encoding. Instead, use the decode(String,String) method
                 to specify the encoding.
        """
        ...


    @staticmethod
    def decode(s: str, enc: str) -> str:
        """
        Decodes an `application/x-www-form-urlencoded` string using
        a specific encoding scheme.
        
        
        This method behaves the same as decode(String s, Charset charset)
        except that it will java.nio.charset.Charset.forName look up the charset
        using the given encoding name.

        Arguments
        - s: the `String` to decode
        - enc: The name of a supported
           <a href="../lang/package-summary.html#charenc">character
           encoding</a>.

        Returns
        - the newly decoded `String`

        Raises
        - UnsupportedEncodingException: If character encoding needs to be consulted, but
                    named character encoding is not supported

        See
        - URLEncoder.encode(java.lang.String, java.lang.String)

        Since
        - 1.4

        Unknown Tags
        - This implementation will throw an java.lang.IllegalArgumentException
        when illegal strings are encountered.
        """
        ...


    @staticmethod
    def decode(s: str, charset: "Charset") -> str:
        """
        Decodes an `application/x-www-form-urlencoded` string using
        a specific java.nio.charset.Charset Charset.
        The supplied charset is used to determine
        what characters are represented by any consecutive sequences of the
        form "*`%xy`*".
        
        *<strong>Note:</strong> The <a href=
        "http://www.w3.org/TR/html40/appendix/notes.html#non-ascii-chars">
        World Wide Web Consortium Recommendation</a> states that
        UTF-8 should be used. Not doing so may introduce
        incompatibilities.*

        Arguments
        - s: the `String` to decode
        - charset: the given charset

        Returns
        - the newly decoded `String`

        Raises
        - NullPointerException: if `s` or `charset` is `null`
        - IllegalArgumentException: if the implementation encounters illegal
        characters

        See
        - URLEncoder.encode(java.lang.String, java.nio.charset.Charset)

        Since
        - 10

        Unknown Tags
        - This implementation will throw an java.lang.IllegalArgumentException
        when illegal strings are encountered.
        """
        ...



"""
Python module generated from Java source file org.bukkit.inventory.EquipmentSlot

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from java.util.function import Supplier
from org.bukkit.inventory import *
from typing import Any, Callable, Iterable, Tuple


class EquipmentSlot(Enum):

    HAND = (() -> EquipmentSlotGroup.MAINHAND)
    OFF_HAND = (() -> EquipmentSlotGroup.OFFHAND)
    FEET = (() -> EquipmentSlotGroup.FEET)
    LEGS = (() -> EquipmentSlotGroup.LEGS)
    CHEST = (() -> EquipmentSlotGroup.CHEST)
    HEAD = (() -> EquipmentSlotGroup.HEAD)
    BODY = (() -> EquipmentSlotGroup.ARMOR)
    """
    Only for certain entities such as horses and wolves.
    """


    def getGroup(self) -> "EquipmentSlotGroup":
        """
        Gets the EquipmentSlotGroup corresponding to this slot.

        Returns
        - corresponding EquipmentSlotGroup
        """
        ...



from .BaseConstructor import BaseConstructor
from .DuplicateKeyException import DuplicateKeyException
from .Construct import Construct
from .CustomClassLoaderConstructor import CustomClassLoaderConstructor
from .AbstractConstruct import AbstractConstruct
from .ConstructorException import ConstructorException
from .SafeConstructor import SafeConstructor
from .Constructor import Constructor


"""
Python module generated from Java source file org.bukkit.plugin.PluginBase

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class PluginBase(Plugin):
    """
    Represents a base Plugin
    
    Extend this class if your plugin is not a org.bukkit.plugin.java.JavaPlugin
    """

    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def getName(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.inventory.meta.FireworkEffectMeta

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import FireworkEffect
from org.bukkit import Material
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class FireworkEffectMeta(ItemMeta):
    """
    Represents a meta that can store a single FireworkEffect. An example
    includes Material.FIREWORK_STAR.
    """

    def setEffect(self, effect: "FireworkEffect") -> None:
        """
        Sets the firework effect for this meta.

        Arguments
        - effect: the effect to set, or null to indicate none.
        """
        ...


    def hasEffect(self) -> bool:
        """
        Checks if this meta has an effect.

        Returns
        - True if this meta has an effect, False otherwise
        """
        ...


    def getEffect(self) -> "FireworkEffect":
        """
        Gets the firework effect for this meta.

        Returns
        - the current effect, or null if none
        """
        ...


    def clone(self) -> "FireworkEffectMeta":
        ...



"""
Python module generated from Java source file org.bukkit.plugin.AuthorNagException

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import *
from typing import Any, Callable, Iterable, Tuple


class AuthorNagException(RuntimeException):

    def __init__(self, message: str):
        """
        Constructs a new AuthorNagException based on the given Exception

        Arguments
        - message: Brief message explaining the cause of the exception
        """
        ...


    def getMessage(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.block.data.MultipleFacing

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import BlockFace
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class MultipleFacing(BlockData):
    """
    This class encompasses the 'north', 'east', 'south', 'west', 'up', 'down'
    boolean flags which are used to set which faces of the block textures are
    displayed on.
    
    Some blocks may not be able to have faces on all directions, use
    .getAllowedFaces() to get all possible faces for this block. It is
    not valid to call any methods on non-allowed faces.
    """

    def hasFace(self, face: "BlockFace") -> bool:
        """
        Checks if this block has the specified face enabled.

        Arguments
        - face: to check

        Returns
        - if face is enabled
        """
        ...


    def setFace(self, face: "BlockFace", has: bool) -> None:
        """
        Set whether this block has the specified face enabled.

        Arguments
        - face: to set
        - has: the face
        """
        ...


    def getFaces(self) -> set["BlockFace"]:
        """
        Get all of the faces which are enabled on this block.

        Returns
        - all faces enabled
        """
        ...


    def getAllowedFaces(self) -> set["BlockFace"]:
        """
        Gets all of this faces which may be set on this block.

        Returns
        - all allowed faces
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.SingletonImmutableBiMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import RetainedWith
from java.util.function import BiConsumer
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class SingletonImmutableBiMap(ImmutableBiMap):
    """
    Implementation of ImmutableMap with exactly one entry.

    Author(s)
    - Kevin Bourrillion
    """

    def get(self, key: "Object") -> "V":
        ...


    def size(self) -> int:
        ...


    def forEach(self, action: "BiConsumer"["K", "V"]) -> None:
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def inverse(self) -> "ImmutableBiMap"["V", "K"]:
        ...



"""
Python module generated from Java source file org.bukkit.Chunk

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import *
from org.bukkit.block import Biome
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.block.data import BlockData
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.generator.structure import GeneratedStructure
from org.bukkit.generator.structure import Structure
from org.bukkit.persistence import PersistentDataHolder
from org.bukkit.plugin import Plugin
from typing import Any, Callable, Iterable, Tuple


class Chunk(PersistentDataHolder):
    """
    Represents a chunk of blocks.
    
    If the chunk is not yet fully generated and data is requested from the chunk,
    then the chunk will only be generated as far as it needs to provide the
    requested data.
    """

    def getX(self) -> int:
        """
        Gets the X-coordinate of this chunk

        Returns
        - X-coordinate
        """
        ...


    def getZ(self) -> int:
        """
        Gets the Z-coordinate of this chunk

        Returns
        - Z-coordinate
        """
        ...


    def getWorld(self) -> "World":
        """
        Gets the world containing this chunk

        Returns
        - Parent World
        """
        ...


    def getBlock(self, x: int, y: int, z: int) -> "Block":
        """
        Gets a block from this chunk

        Arguments
        - x: 0-15
        - y: world minHeight (inclusive) - world maxHeight (exclusive)
        - z: 0-15

        Returns
        - the Block
        """
        ...


    def getChunkSnapshot(self) -> "ChunkSnapshot":
        """
        Capture thread-safe read-only snapshot of chunk data

        Returns
        - ChunkSnapshot
        """
        ...


    def getChunkSnapshot(self, includeMaxblocky: bool, includeBiome: bool, includeBiomeTempRain: bool) -> "ChunkSnapshot":
        """
        Capture thread-safe read-only snapshot of chunk data

        Arguments
        - includeMaxblocky: - if True, snapshot includes per-coordinate
            maximum Y values
        - includeBiome: - if True, snapshot includes per-coordinate biome
            type
        - includeBiomeTempRain: - if True, snapshot includes per-coordinate
            raw biome temperature and rainfall

        Returns
        - ChunkSnapshot
        """
        ...


    def isEntitiesLoaded(self) -> bool:
        """
        Checks if entities in this chunk are loaded.

        Returns
        - True if entities are loaded.
        """
        ...


    def getEntities(self) -> list["Entity"]:
        """
        Get a list of all entities in the chunk.
        This will force load any entities, which are not loaded.

        Returns
        - The entities.
        """
        ...


    def getTileEntities(self) -> list["BlockState"]:
        """
        Get a list of all tile entities in the chunk.

        Returns
        - The tile entities.
        """
        ...


    def isGenerated(self) -> bool:
        """
        Checks if the chunk is fully generated.

        Returns
        - True if it is fully generated.
        """
        ...


    def isLoaded(self) -> bool:
        """
        Checks if the chunk is loaded.

        Returns
        - True if it is loaded.
        """
        ...


    def load(self, generate: bool) -> bool:
        """
        Loads the chunk.

        Arguments
        - generate: Whether or not to generate a chunk if it doesn't
            already exist

        Returns
        - True if the chunk has loaded successfully, otherwise False
        """
        ...


    def load(self) -> bool:
        """
        Loads the chunk.

        Returns
        - True if the chunk has loaded successfully, otherwise False
        """
        ...


    def unload(self, save: bool) -> bool:
        """
        Unloads and optionally saves the Chunk

        Arguments
        - save: Controls whether the chunk is saved

        Returns
        - True if the chunk has unloaded successfully, otherwise False
        """
        ...


    def unload(self) -> bool:
        """
        Unloads and optionally saves the Chunk

        Returns
        - True if the chunk has unloaded successfully, otherwise False
        """
        ...


    def isSlimeChunk(self) -> bool:
        """
        Checks if this chunk can spawn slimes without being a swamp biome.

        Returns
        - True if slimes are able to spawn in this chunk
        """
        ...


    def isForceLoaded(self) -> bool:
        """
        Gets whether the chunk at the specified chunk coordinates is force
        loaded.
        
        A force loaded chunk will not be unloaded due to lack of player activity.

        Returns
        - force load status

        See
        - World.isChunkForceLoaded(int, int)
        """
        ...


    def setForceLoaded(self, forced: bool) -> None:
        """
        Sets whether the chunk at the specified chunk coordinates is force
        loaded.
        
        A force loaded chunk will not be unloaded due to lack of player activity.

        Arguments
        - forced: force load status

        See
        - World.setChunkForceLoaded(int, int, boolean)
        """
        ...


    def addPluginChunkTicket(self, plugin: "Plugin") -> bool:
        """
        Adds a plugin ticket for this chunk, loading this chunk if it is not
        already loaded.
        
        A plugin ticket will prevent a chunk from unloading until it is
        explicitly removed. A plugin instance may only have one ticket per chunk,
        but each chunk can have multiple plugin tickets.

        Arguments
        - plugin: Plugin which owns the ticket

        Returns
        - `True` if a plugin ticket was added, `False` if the
        ticket already exists for the plugin

        Raises
        - IllegalStateException: If the specified plugin is not enabled

        See
        - World.addPluginChunkTicket(int, int, Plugin)
        """
        ...


    def removePluginChunkTicket(self, plugin: "Plugin") -> bool:
        """
        Removes the specified plugin's ticket for this chunk
        
        A plugin ticket will prevent a chunk from unloading until it is
        explicitly removed. A plugin instance may only have one ticket per chunk,
        but each chunk can have multiple plugin tickets.

        Arguments
        - plugin: Plugin which owns the ticket

        Returns
        - `True` if the plugin ticket was removed, `False` if
        there is no plugin ticket for the chunk

        See
        - World.removePluginChunkTicket(int, int, Plugin)
        """
        ...


    def getPluginChunkTickets(self) -> Iterable["Plugin"]:
        """
        Retrieves a collection specifying which plugins have tickets for this
        chunk. This collection is not updated when plugin tickets are added or
        removed to this chunk.
        
        A plugin ticket will prevent a chunk from unloading until it is
        explicitly removed. A plugin instance may only have one ticket per chunk,
        but each chunk can have multiple plugin tickets.

        Returns
        - unmodifiable collection containing which plugins have tickets for
        this chunk

        See
        - World.getPluginChunkTickets(int, int)
        """
        ...


    def getInhabitedTime(self) -> int:
        """
        Gets the amount of time in ticks that this chunk has been inhabited.
        
        Note that the time is incremented once per tick per player within mob
        spawning distance of this chunk.

        Returns
        - inhabited time
        """
        ...


    def setInhabitedTime(self, ticks: int) -> None:
        """
        Sets the amount of time in ticks that this chunk has been inhabited.

        Arguments
        - ticks: new inhabited time
        """
        ...


    def contains(self, block: "BlockData") -> bool:
        """
        Tests if this chunk contains the specified block.

        Arguments
        - block: block to test

        Returns
        - if the block is contained within
        """
        ...


    def contains(self, biome: "Biome") -> bool:
        """
        Tests if this chunk contains the specified biome.

        Arguments
        - biome: biome to test

        Returns
        - if the biome is contained within
        """
        ...


    def getLoadLevel(self) -> "LoadLevel":
        """
        Gets the load level of this chunk, which determines what game logic is
        processed.

        Returns
        - the load level
        """
        ...


    def getStructures(self) -> Iterable["GeneratedStructure"]:
        """
        Gets all generated structures that intersect this chunk. 
        If no structures are present an empty collection will be returned.

        Returns
        - a collection of placed structures in this chunk
        """
        ...


    def getStructures(self, structure: "Structure") -> Iterable["GeneratedStructure"]:
        """
        Gets all generated structures of a given Structure that intersect
        this chunk. 
        If no structures are present an empty collection will be returned.

        Arguments
        - structure: the structure to find

        Returns
        - a collection of placed structures in this chunk
        """
        ...


    def getPlayersSeeingChunk(self) -> Iterable["Player"]:
        """
        Get a list of all players who are can view the chunk from their client
        
        This list will be empty if no players are viewing the chunk, or the chunk
        is unloaded.

        Returns
        - collection of players who can see the chunk
        """
        ...


    class LoadLevel(Enum):
        """
        An enum to specify the load level of a chunk.
        """

        INACCESSIBLE = 0
        """
        No game logic is processed, world generation may still occur.
        """
        BORDER = 1
        """
        Most game logic is not processed, including entities and redstone.
        """
        TICKING = 2
        """
        All game logic except entities is processed.
        """
        ENTITY_TICKING = 3
        """
        All game logic is processed.
        """
        UNLOADED = 4
        """
        This chunk is not loaded.
        """



"""
Python module generated from Java source file java.util.stream.Collector

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Collections
from java.util import EnumSet
from java.util import Objects
from java.util.function import BiConsumer
from java.util.function import BinaryOperator
from java.util.function import Function
from java.util.function import Supplier
from java.util.stream import *
from typing import Any, Callable, Iterable, Tuple


class Collector:
    """
    A <a href="package-summary.html#Reduction">mutable reduction operation</a> that
    accumulates input elements into a mutable result container, optionally transforming
    the accumulated result into a final representation after all input elements
    have been processed.  Reduction operations can be performed either sequentially
    or in parallel.
    
    Examples of mutable reduction operations include:
    accumulating elements into a `Collection`; concatenating
    strings using a `StringBuilder`; computing summary information about
    elements such as sum, min, max, or average; computing "pivot table" summaries
    such as "maximum valued transaction by seller", etc.  The class Collectors
    provides implementations of many common mutable reductions.
    
    A `Collector` is specified by four functions that work together to
    accumulate entries into a mutable result container, and optionally perform
    a final transform on the result.  They are: 
        - creation of a new result container (.supplier())
        - incorporating a new data element into a result container (.accumulator())
        - combining two result containers into one (.combiner())
        - performing an optional final transform on the container (.finisher())
    
    
    Collectors also have a set of characteristics, such as
    Characteristics.CONCURRENT, that provide hints that can be used by a
    reduction implementation to provide better performance.
    
    A sequential implementation of a reduction using a collector would
    create a single result container using the supplier function, and invoke the
    accumulator function once for each input element.  A parallel implementation
    would partition the input, create a result container for each partition,
    accumulate the contents of each partition into a subresult for that partition,
    and then use the combiner function to merge the subresults into a combined
    result.
    
    To ensure that sequential and parallel executions produce equivalent
    results, the collector functions must satisfy an *identity* and an
    <a href="package-summary.html#Associativity">associativity</a> constraints.
    
    The identity constraint says that for any partially accumulated result,
    combining it with an empty result container must produce an equivalent
    result.  That is, for a partially accumulated result `a` that is the
    result of any series of accumulator and combiner invocations, `a` must
    be equivalent to `combiner.apply(a, supplier.get())`.
    
    The associativity constraint says that splitting the computation must
    produce an equivalent result.  That is, for any input elements `t1`
    and `t2`, the results `r1` and `r2` in the computation
    below must be equivalent:
    ````A a1 = supplier.get();
        accumulator.accept(a1, t1);
        accumulator.accept(a1, t2);
        R r1 = finisher.apply(a1);  // result without splitting
    
        A a2 = supplier.get();
        accumulator.accept(a2, t1);
        A a3 = supplier.get();
        accumulator.accept(a3, t2);
        R r2 = finisher.apply(combiner.apply(a2, a3));  // result with splitting` ```
    
    For collectors that do not have the `UNORDERED` characteristic,
    two accumulated results `a1` and `a2` are equivalent if
    `finisher.apply(a1).equals(finisher.apply(a2))`.  For unordered
    collectors, equivalence is relaxed to allow for non-equality related to
    differences in order.  (For example, an unordered collector that accumulated
    elements to a `List` would consider two lists equivalent if they
    contained the same elements, ignoring order.)
    
    Libraries that implement reduction based on `Collector`, such as
    Stream.collect(Collector), must adhere to the following constraints:
    
        - The first argument passed to the accumulator function, both
        arguments passed to the combiner function, and the argument passed to the
        finisher function must be the result of a previous invocation of the
        result supplier, accumulator, or combiner functions.
        - The implementation should not do anything with the result of any of
        the result supplier, accumulator, or combiner functions other than to
        pass them again to the accumulator, combiner, or finisher functions,
        or return them to the caller of the reduction operation.
        - If a result is passed to the combiner or finisher
        function, and the same object is not returned from that function, it is
        never used again.
        - Once a result is passed to the combiner or finisher function, it
        is never passed to the accumulator function again.
        - For non-concurrent collectors, any result returned from the result
        supplier, accumulator, or combiner functions must be serially
        thread-confined.  This enables collection to occur in parallel without
        the `Collector` needing to implement any additional synchronization.
        The reduction implementation must manage that the input is properly
        partitioned, that partitions are processed in isolation, and combining
        happens only after accumulation is complete.
        - For concurrent collectors, an implementation is free to (but not
        required to) implement reduction concurrently.  A concurrent reduction
        is one where the accumulator function is called concurrently from
        multiple threads, using the same concurrently-modifiable result container,
        rather than keeping the result isolated during accumulation.
        A concurrent reduction should only be applied if the collector has the
        Characteristics.UNORDERED characteristics or if the
        originating data is unordered.
    
    
    In addition to the predefined implementations in Collectors, the
    static factory methods .of(Supplier, BiConsumer, BinaryOperator, Characteristics...)
    can be used to construct collectors.  For example, you could create a collector
    that accumulates widgets into a `TreeSet` with:
    
    ````Collector<Widget, ?, TreeSet<Widget>> intoSet =
            Collector.of(TreeSet::new, TreeSet::add,
                         (left, right) -> { left.addAll(right); return left;`);
    }```
    
    (This behavior is also implemented by the predefined collector
    Collectors.toCollection(Supplier)).
    
    Type `<T>`: the type of input elements to the reduction operation
    
    Type `<A>`: the mutable accumulation type of the reduction operation (often
               hidden as an implementation detail)
    
    Type `<R>`: the result type of the reduction operation

    See
    - Collectors

    Since
    - 1.8

    Unknown Tags
    - Performing a reduction operation with a `Collector` should produce a
    result equivalent to:
    ````A container = collector.supplier().get();
        for (T t : data)
            collector.accumulator().accept(container, t);
        return collector.finisher().apply(container);````
    
    However, the library is free to partition the input, perform the reduction
    on the partitions, and then use the combiner function to combine the partial
    results to achieve a parallel reduction.  (Depending on the specific reduction
    operation, this may perform better or worse, depending on the relative cost
    of the accumulator and combiner functions.)
    
    Collectors are designed to be *composed*; many of the methods
    in Collectors are functions that take a collector and produce
    a new collector.  For example, given the following collector that computes
    the sum of the salaries of a stream of employees:
    
    ````Collector<Employee, ?, Integer> summingSalaries
            = Collectors.summingInt(Employee::getSalary))````
    
    If we wanted to create a collector to tabulate the sum of salaries by
    department, we could reuse the "sum of salaries" logic using
    Collectors.groupingBy(Function, Collector):
    
    ````Collector<Employee, ?, Map<Department, Integer>> summingSalariesByDept
            = Collectors.groupingBy(Employee::getDepartment, summingSalaries);````
    """

    def supplier(self) -> "Supplier"["A"]:
        """
        A function that creates and returns a new mutable result container.

        Returns
        - a function which returns a new, mutable result container
        """
        ...


    def accumulator(self) -> "BiConsumer"["A", "T"]:
        """
        A function that folds a value into a mutable result container.

        Returns
        - a function which folds a value into a mutable result container
        """
        ...


    def combiner(self) -> "BinaryOperator"["A"]:
        """
        A function that accepts two partial results and merges them.  The
        combiner function may fold state from one argument into the other and
        return that, or may return a new result container.

        Returns
        - a function which combines two partial results into a combined
        result
        """
        ...


    def finisher(self) -> "Function"["A", "R"]:
        """
        Perform the final transformation from the intermediate accumulation type
        `A` to the final result type `R`.
        
        If the characteristic `IDENTITY_FINISH` is
        set, this function may be presumed to be an identity transform with an
        unchecked cast from `A` to `R`.

        Returns
        - a function which transforms the intermediate result to the final
        result
        """
        ...


    def characteristics(self) -> set["Characteristics"]:
        """
        Returns a `Set` of `Collector.Characteristics` indicating
        the characteristics of this Collector.  This set should be immutable.

        Returns
        - an immutable set of collector characteristics
        """
        ...


    @staticmethod
    def of(supplier: "Supplier"["R"], accumulator: "BiConsumer"["R", "T"], combiner: "BinaryOperator"["R"], *characteristics: Tuple["Characteristics", ...]) -> "Collector"["T", "R", "R"]:
        """
        Returns a new `Collector` described by the given `supplier`,
        `accumulator`, and `combiner` functions.  The resulting
        `Collector` has the `Collector.Characteristics.IDENTITY_FINISH`
        characteristic.
        
        Type `<T>`: The type of input elements for the new collector
        
        Type `<R>`: The type of intermediate accumulation result, and final result,
                  for the new collector

        Arguments
        - supplier: The supplier function for the new collector
        - accumulator: The accumulator function for the new collector
        - combiner: The combiner function for the new collector
        - characteristics: The collector characteristics for the new
                               collector

        Returns
        - the new `Collector`

        Raises
        - NullPointerException: if any argument is null
        """
        ...


    @staticmethod
    def of(supplier: "Supplier"["A"], accumulator: "BiConsumer"["A", "T"], combiner: "BinaryOperator"["A"], finisher: "Function"["A", "R"], *characteristics: Tuple["Characteristics", ...]) -> "Collector"["T", "A", "R"]:
        """
        Returns a new `Collector` described by the given `supplier`,
        `accumulator`, `combiner`, and `finisher` functions.
        
        Type `<T>`: The type of input elements for the new collector
        
        Type `<A>`: The intermediate accumulation type of the new collector
        
        Type `<R>`: The final result type of the new collector

        Arguments
        - supplier: The supplier function for the new collector
        - accumulator: The accumulator function for the new collector
        - combiner: The combiner function for the new collector
        - finisher: The finisher function for the new collector
        - characteristics: The collector characteristics for the new
                               collector

        Returns
        - the new `Collector`

        Raises
        - NullPointerException: if any argument is null
        """
        ...



"""
Python module generated from Java source file com.google.common.base.SmallCharMatcher

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import *
from com.google.common.base.CharMatcher import NamedFastMatcher
from java.util import BitSet
from typing import Any, Callable, Iterable, Tuple


class SmallCharMatcher(NamedFastMatcher):
    """
    An immutable version of CharMatcher for smallish sets of characters that uses a hash table with
    linear probing to check for matches.

    Author(s)
    - Christopher Swenson
    """

    def matches(self, c: str) -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.event.block.SpongeAbsorbEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class SpongeAbsorbEvent(BlockEvent, Cancellable):
    """
    Called when a sponge absorbs water from the world.
    
    The world will be in its previous state, and .getBlocks() will
    represent the changes to be made to the world, if the event is not cancelled.
    
    As this is a physics based event it may be called multiple times for "the
    same" changes.
    """

    def __init__(self, block: "Block", waterblocks: list["BlockState"]):
        ...


    def getBlocks(self) -> list["BlockState"]:
        """
        Get a list of all blocks to be removed by the sponge.
        
        This list is mutable and contains the blocks in their removed state, i.e.
        having a type of Material.AIR.

        Returns
        - list of the to be removed blocks.
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.net.URLEncoder

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import CharArrayWriter
from java.io import UnsupportedEncodingException
from java.net import *
from java.nio.charset import Charset
from java.nio.charset import IllegalCharsetNameException
from java.nio.charset import UnsupportedCharsetException
from java.util import BitSet
from java.util import Objects
from sun.security.action import GetPropertyAction
from typing import Any, Callable, Iterable, Tuple


class URLEncoder:
    """
    Utility class for HTML form encoding. This class contains static methods
    for converting a String to the <CODE>application/x-www-form-urlencoded</CODE> MIME
    format. For more information about HTML form encoding, consult the HTML
    <A HREF="http://www.w3.org/TR/html4/">specification</A>.
    
    
    When encoding a String, the following rules apply:
    
    
    - The alphanumeric characters &quot;`a`&quot; through
        &quot;`z`&quot;, &quot;`A`&quot; through
        &quot;`Z`&quot; and &quot;`0`&quot;
        through &quot;`9`&quot; remain the same.
    - The special characters &quot;`.`&quot;,
        &quot;`-`&quot;, &quot;`*`&quot;, and
        &quot;`_`&quot; remain the same.
    - The space character &quot; &nbsp; &quot; is
        converted into a plus sign &quot;`+`&quot;.
    - All other characters are unsafe and are first converted into
        one or more bytes using some encoding scheme. Then each byte is
        represented by the 3-character string
        &quot;*`%xy`*&quot;, where *xy* is the
        two-digit hexadecimal representation of the byte.
        The recommended encoding scheme to use is UTF-8. However,
        for compatibility reasons, if an encoding is not specified,
        then the default encoding of the platform is used.
    
    
    
    For example using UTF-8 as the encoding scheme the string &quot;The
    string &#252;@foo-bar&quot; would get converted to
    &quot;The+string+%C3%BC%40foo-bar&quot; because in UTF-8 the character
    &#252; is encoded as two bytes C3 (hex) and BC (hex), and the
    character @ is encoded as one byte 40 (hex).

    Author(s)
    - Herb Jellinek

    Since
    - 1.0
    """

    @staticmethod
    def encode(s: str) -> str:
        """
        Translates a string into `x-www-form-urlencoded`
        format. This method uses the platform's default encoding
        as the encoding scheme to obtain the bytes for unsafe characters.

        Arguments
        - s: `String` to be translated.

        Returns
        - the translated `String`.

        Deprecated
        - The resulting string may vary depending on the platform's
                    default encoding. Instead, use the encode(String,String)
                    method to specify the encoding.
        """
        ...


    @staticmethod
    def encode(s: str, enc: str) -> str:
        """
        Translates a string into `application/x-www-form-urlencoded`
        format using a specific encoding scheme.
        
        This method behaves the same as .encode(String s, Charset charset)
        except that it will java.nio.charset.Charset.forName look up the charset
        using the given encoding name.

        Arguments
        - s: `String` to be translated.
        - enc: The name of a supported
           <a href="../lang/package-summary.html#charenc">character
           encoding</a>.

        Returns
        - the translated `String`.

        Raises
        - UnsupportedEncodingException: If the named encoding is not supported

        See
        - URLDecoder.decode(java.lang.String, java.lang.String)

        Since
        - 1.4
        """
        ...


    @staticmethod
    def encode(s: str, charset: "Charset") -> str:
        """
        Translates a string into `application/x-www-form-urlencoded`
        format using a specific java.nio.charset.Charset Charset.
        This method uses the supplied charset to obtain the bytes for unsafe
        characters.
        
        *<strong>Note:</strong> The <a href=
        "http://www.w3.org/TR/html40/appendix/notes.html#non-ascii-chars">
        World Wide Web Consortium Recommendation</a> states that
        UTF-8 should be used. Not doing so may introduce incompatibilities.*

        Arguments
        - s: `String` to be translated.
        - charset: the given charset

        Returns
        - the translated `String`.

        Raises
        - NullPointerException: if `s` or `charset` is `null`.

        See
        - URLDecoder.decode(java.lang.String, java.nio.charset.Charset)

        Since
        - 10
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.SortedLists

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Function
from com.google.common.collect import *
from java.util import Collections
from java.util import Comparator
from java.util import RandomAccess
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class SortedLists:
    """
    Static methods pertaining to sorted List instances.
    
    In this documentation, the terms *greatest*, *greater*, *least*, and
    *lesser* are considered to refer to the comparator on the elements, and the terms
    *first* and *last* are considered to refer to the elements' ordering in a list.

    Author(s)
    - Louis Wasserman
    """

    @staticmethod
    def binarySearch(list: list["E"], e: "E", presentBehavior: "KeyPresentBehavior", absentBehavior: "KeyAbsentBehavior") -> int:
        """
        Searches the specified naturally ordered list for the specified object using the binary search
        algorithm.
        
        Equivalent to .binarySearch(List, Function, Object, Comparator, KeyPresentBehavior,
        KeyAbsentBehavior) using Ordering.natural.
        """
        ...


    @staticmethod
    def binarySearch(list: list["E"], keyFunction: "Function"["E", "K"], key: "K", presentBehavior: "KeyPresentBehavior", absentBehavior: "KeyAbsentBehavior") -> int:
        """
        Binary searches the list for the specified key, using the specified key function.
        
        Equivalent to .binarySearch(List, Function, Object, Comparator, KeyPresentBehavior,
        KeyAbsentBehavior) using Ordering.natural.
        """
        ...


    @staticmethod
    def binarySearch(list: list["E"], keyFunction: "Function"["E", "K"], key: "K", keyComparator: "Comparator"["K"], presentBehavior: "KeyPresentBehavior", absentBehavior: "KeyAbsentBehavior") -> int:
        """
        Binary searches the list for the specified key, using the specified key function.
        
        Equivalent to .binarySearch(List, Object, Comparator, KeyPresentBehavior,
        KeyAbsentBehavior) using Lists.transform(List, Function) Lists.transform(list,
        keyFunction).
        """
        ...


    @staticmethod
    def binarySearch(list: list["E"], key: "E", comparator: "Comparator"["E"], presentBehavior: "KeyPresentBehavior", absentBehavior: "KeyAbsentBehavior") -> int:
        """
        Searches the specified list for the specified object using the binary search algorithm. The
        list must be sorted into ascending order according to the specified comparator (as by the
        Collections.sort(List, Comparator) Collections.sort(List, Comparator) method), prior to
        making this call. If it is not sorted, the results are undefined.
        
        If there are elements in the list which compare as equal to the key, the choice of KeyPresentBehavior decides which index is returned. If no elements compare as equal to the
        key, the choice of KeyAbsentBehavior decides which index is returned.
        
        This method runs in log(n) time on random-access lists, which offer near-constant-time
        access to each list element.

        Arguments
        - list: the list to be searched.
        - key: the value to be searched for.
        - comparator: the comparator by which the list is ordered.
        - presentBehavior: the specification for what to do if at least one element of the list
            compares as equal to the key.
        - absentBehavior: the specification for what to do if no elements of the list compare as
            equal to the key.

        Returns
        - the index determined by the `KeyPresentBehavior`, if the key is in the list;
            otherwise the index determined by the `KeyAbsentBehavior`.
        """
        ...



"""
Python module generated from Java source file org.bukkit.command.PluginCommand

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from org.bukkit.command import *
from org.bukkit.plugin import Plugin
from typing import Any, Callable, Iterable, Tuple


class PluginCommand(Command, PluginIdentifiableCommand):
    """
    Represents a Command belonging to a plugin
    """

    def execute(self, sender: "CommandSender", commandLabel: str, args: list[str]) -> bool:
        """
        Executes the command, returning its success

        Arguments
        - sender: Source object which is executing this command
        - commandLabel: The alias of the command used
        - args: All arguments passed to the command, split via ' '

        Returns
        - True if the command was successful, otherwise False
        """
        ...


    def setExecutor(self, executor: "CommandExecutor") -> None:
        """
        Sets the CommandExecutor to run when parsing this command

        Arguments
        - executor: New executor to run
        """
        ...


    def getExecutor(self) -> "CommandExecutor":
        """
        Gets the CommandExecutor associated with this command

        Returns
        - CommandExecutor object linked to this command
        """
        ...


    def setTabCompleter(self, completer: "TabCompleter") -> None:
        """
        Sets the TabCompleter to run when tab-completing this command.
        
        If no TabCompleter is specified, and the command's executor implements
        TabCompleter, then the executor will be used for tab completion.

        Arguments
        - completer: New tab completer
        """
        ...


    def getTabCompleter(self) -> "TabCompleter":
        """
        Gets the TabCompleter associated with this command.

        Returns
        - TabCompleter object linked to this command
        """
        ...


    def getPlugin(self) -> "Plugin":
        """
        Gets the owner of this PluginCommand

        Returns
        - Plugin that owns this command
        """
        ...


    def tabComplete(self, sender: "CommandSender", alias: str, args: list[str]) -> "java.util.List"[str]:
        """
        
        
        Delegates to the tab completer if present.
        
        If it is not present or returns null, will delegate to the current
        command executor if it implements TabCompleter. If a non-null
        list has not been found, will default to standard player name
        completion in Command.tabComplete(CommandSender, String, String[]).
        
        This method does not consider permissions.

        Raises
        - CommandException: if the completer or executor throw an
            exception during the process of tab-completing.
        - IllegalArgumentException: if sender, alias, or args is null
        """
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.attribute.Attributable

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.attribute import *
from typing import Any, Callable, Iterable, Tuple


class Attributable:
    """
    Represents an object which may contain attributes.
    """

    def getAttribute(self, attribute: "Attribute") -> "AttributeInstance":
        """
        Gets the specified attribute instance from the object. This instance will
        be backed directly to the object and any changes will be visible at once.

        Arguments
        - attribute: the attribute to get

        Returns
        - the attribute instance or null if not applicable to this object
        """
        ...



"""
Python module generated from Java source file com.google.common.graph.StandardNetwork

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ImmutableSet
from com.google.common.graph import *
from typing import Any, Callable, Iterable, Tuple


class StandardNetwork(AbstractNetwork):
    """
    Standard implementation of Network that supports the options supplied by NetworkBuilder.
    
    This class maintains a map of nodes to NetworkConnections. This class also maintains a
    map of edges to reference nodes. The reference node is defined to be the edge's source node on
    directed graphs, and an arbitrary endpoint of the edge on undirected graphs.
    
    Collection-returning accessors return unmodifiable views: the view returned will reflect
    changes to the graph (if the graph is mutable) but may not be modified by the user.
    
    The time complexity of all collection-returning accessors is O(1), since views are returned.
    
    Type `<N>`: Node parameter type
    
    Type `<E>`: Edge parameter type

    Author(s)
    - Omar Darwish
    """

    def nodes(self) -> set["N"]:
        ...


    def edges(self) -> set["E"]:
        ...


    def isDirected(self) -> bool:
        ...


    def allowsParallelEdges(self) -> bool:
        ...


    def allowsSelfLoops(self) -> bool:
        ...


    def nodeOrder(self) -> "ElementOrder"["N"]:
        ...


    def edgeOrder(self) -> "ElementOrder"["E"]:
        ...


    def incidentEdges(self, node: "N") -> set["E"]:
        ...


    def incidentNodes(self, edge: "E") -> "EndpointPair"["N"]:
        ...


    def adjacentNodes(self, node: "N") -> set["N"]:
        ...


    def edgesConnecting(self, nodeU: "N", nodeV: "N") -> set["E"]:
        ...


    def inEdges(self, node: "N") -> set["E"]:
        ...


    def outEdges(self, node: "N") -> set["E"]:
        ...


    def predecessors(self, node: "N") -> set["N"]:
        ...


    def successors(self, node: "N") -> set["N"]:
        ...



"""
Python module generated from Java source file java.io.ObjectStreamClass

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.lang.invoke import MethodHandle
from java.lang.invoke import MethodHandles
from java.lang.invoke import MethodType
from java.lang.ref import Reference
from java.lang.ref import ReferenceQueue
from java.lang.ref import WeakReference
from java.lang.reflect import Constructor
from java.lang.reflect import Field
from java.lang.reflect import InvocationTargetException
from java.lang.reflect import Member
from java.lang.reflect import Method
from java.lang.reflect import Modifier
from java.lang.reflect import Proxy
from java.lang.reflect import RecordComponent
from java.lang.reflect import UndeclaredThrowableException
from java.security import AccessControlContext
from java.security import AccessController
from java.security import MessageDigest
from java.security import NoSuchAlgorithmException
from java.security import PermissionCollection
from java.security import Permissions
from java.security import PrivilegedAction
from java.security import PrivilegedActionException
from java.security import PrivilegedExceptionAction
from java.security import ProtectionDomain
from java.util import Arrays
from java.util import Collections
from java.util import Comparator
from java.util.concurrent import ConcurrentHashMap
from java.util.concurrent import ConcurrentMap
from jdk.internal.access import JavaSecurityAccess
from jdk.internal.access import SharedSecrets
from jdk.internal.misc import Unsafe
from jdk.internal.reflect import CallerSensitive
from jdk.internal.reflect import Reflection
from jdk.internal.reflect import ReflectionFactory
from sun.reflect.misc import ReflectUtil
from typing import Any, Callable, Iterable, Tuple


class ObjectStreamClass(Serializable):
    """
    Serialization's descriptor for classes.  It contains the name and
    serialVersionUID of the class.  The ObjectStreamClass for a specific class
    loaded in this Java VM can be found/created using the lookup method.
    
    The algorithm to compute the SerialVersionUID is described in
    <a href="/../specs/serialization/class.html#stream-unique-identifiers">
       <cite>Java Object Serialization Specification,</cite> Section 4.6, "Stream Unique Identifiers"</a>.

    Author(s)
    - Roger Riggs

    See
    - <a href="/../specs/serialization/class.html">
         <cite>Java Object Serialization Specification,</cite> Section 4, "Class Descriptors"</a>

    Since
    - 1.1
    """

    NO_FIELDS = ObjectStreamField[0]
    """
    serialPersistentFields value indicating no serializable fields
    """


    @staticmethod
    def lookup(cl: type[Any]) -> "ObjectStreamClass":
        """
        Find the descriptor for a class that can be serialized.  Creates an
        ObjectStreamClass instance if one does not exist yet for class. Null is
        returned if the specified class does not implement java.io.Serializable
        or java.io.Externalizable.

        Arguments
        - cl: class for which to get the descriptor

        Returns
        - the class descriptor for the specified class
        """
        ...


    @staticmethod
    def lookupAny(cl: type[Any]) -> "ObjectStreamClass":
        """
        Returns the descriptor for any class, regardless of whether it
        implements Serializable.

        Arguments
        - cl: class for which to get the descriptor

        Returns
        - the class descriptor for the specified class

        Since
        - 1.6
        """
        ...


    def getName(self) -> str:
        """
        Returns the name of the class described by this descriptor.
        This method returns the name of the class in the format that
        is used by the Class.getName method.

        Returns
        - a string representing the name of the class
        """
        ...


    def getSerialVersionUID(self) -> int:
        """
        Return the serialVersionUID for this class.  The serialVersionUID
        defines a set of classes all with the same name that have evolved from a
        common root class and agree to be serialized and deserialized using a
        common format.  NonSerializable classes have a serialVersionUID of 0L.

        Returns
        - the SUID of the class described by this descriptor
        """
        ...


    def forClass(self) -> type[Any]:
        """
        Return the class in the local VM that this version is mapped to.  Null
        is returned if there is no corresponding local class.

        Returns
        - the `Class` instance that this descriptor represents
        """
        ...


    def getFields(self) -> list["ObjectStreamField"]:
        """
        Return an array of the fields of this serializable class.

        Returns
        - an array containing an element for each persistent field of
                 this class. Returns an array of length zero if there are no
                 fields.

        Since
        - 1.2
        """
        ...


    def getField(self, name: str) -> "ObjectStreamField":
        """
        Get the field of this class by name.

        Arguments
        - name: the name of the data field to look for

        Returns
        - The ObjectStreamField object of the named field or null if
                 there is no such named field.
        """
        ...


    def toString(self) -> str:
        """
        Return a string describing this ObjectStreamClass.
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BlockPhysicsEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import Block
from org.bukkit.block.data import BlockData
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockPhysicsEvent(BlockEvent, Cancellable):
    """
    Thrown when a block physics check is called.
    
    This event is a high frequency event, it may be called thousands of times per
    a second on a busy server. Plugins are advised to listen to the event with
    caution and only perform lightweight checks when using it.
    
    In addition to this, cancelling the event is liable to leave the world in an
    inconsistent state. For example if you use the event to leave a block
    floating in mid air when that block has a requirement to be attached to
    something, there is no guarantee that the floating block will persist across
    server restarts or map upgrades.
    
    Plugins should also note that where possible this event may only called for
    the "root" block of physics updates in order to limit event spam. Physics
    updates that cause other blocks to change their state may not result in an
    event for each of those blocks (usually adjacent). If you are concerned about
    monitoring these changes then you should check adjacent blocks yourself.
    """

    def __init__(self, block: "Block", changed: "BlockData"):
        ...


    def __init__(self, block: "Block", changed: "BlockData", sourceBlock: "Block"):
        ...


    def getSourceBlock(self) -> "Block":
        """
        Gets the source block that triggered this event.
        
        Note: This will default to block if not set.

        Returns
        - The source block
        """
        ...


    def getChangedType(self) -> "Material":
        """
        Gets the type of block that changed, causing this event

        Returns
        - Changed block's type
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file java.util.function.BinaryOperator

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Comparator
from java.util import Objects
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class BinaryOperator(BiFunction):
    """
    Represents an operation upon two operands of the same type, producing a result
    of the same type as the operands.  This is a specialization of
    BiFunction for the case where the operands and the result are all of
    the same type.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .apply(Object, Object).
    
    Type `<T>`: the type of the operands and result of the operator

    See
    - UnaryOperator

    Since
    - 1.8
    """

    @staticmethod
    def minBy(comparator: "Comparator"["T"]) -> "BinaryOperator"["T"]:
        """
        Returns a BinaryOperator which returns the lesser of two elements
        according to the specified `Comparator`.
        
        Type `<T>`: the type of the input arguments of the comparator

        Arguments
        - comparator: a `Comparator` for comparing the two values

        Returns
        - a `BinaryOperator` which returns the lesser of its operands,
                according to the supplied `Comparator`

        Raises
        - NullPointerException: if the argument is null
        """
        ...


    @staticmethod
    def maxBy(comparator: "Comparator"["T"]) -> "BinaryOperator"["T"]:
        """
        Returns a BinaryOperator which returns the greater of two elements
        according to the specified `Comparator`.
        
        Type `<T>`: the type of the input arguments of the comparator

        Arguments
        - comparator: a `Comparator` for comparing the two values

        Returns
        - a `BinaryOperator` which returns the greater of its operands,
                according to the supplied `Comparator`

        Raises
        - NullPointerException: if the argument is null
        """
        ...
